@@ -1,11 +1,10 @@
 """A combinator library for designing algorithms."""
 
-from redex import util, stack, function, operator, combinator
+from redex import util, stack, function, combinator
 
 __all__ = [
     "util",
     "stack",
     "function",
-    "operator",
     "combinator",
 ]
